==> khttrack-0.10.tar.bz2: khttrack-0.10/khttrack/khttrackmirrorc.h <==
/***************************************************************************
                          khttrackmirrorc.h  -  C link to C++
                             -------------------
    begin                : Wed Sep 4 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly@ifrance.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef __cplusplus
  extern "C" {
#endif /* __cplusplus */

  void htinfo_link_detected(char *chaine);
  void htinfo_mirror_info(char *chaine);
  void htinfo_bytes_saved(char *chaine);
  void htinfo_time(char *chaine);
  void htinfo_files_written(char *chaine);
  void htinfo_transfer_rate(char *chaine);
  void htinfo_files_updated(char *chaine);
  void htinfo_active_connections(char *chaine);
  void htinfo_errors(char *chaine);
  void htinfo_state_url(char *chaine);
  void htinfo_state_url1(char *chaine);
  void htinfo_state_url2(char *chaine);
  void htinfo_state_url3(char *chaine);
  void htinfo_state_url4(char *chaine);
  void htinfo_state_url5(char *chaine);
  void htinfo_state_url6(char *chaine);
  void htinfo_state_url7(char *chaine);
  void htinfo_state_url8(char *chaine);
  void htinfo_state_url9(char *chaine);
  void htinfo_state_url10(char *chaine);
  void htinfo_state_url11(char *chaine);
  void htinfo_state_url12(char *chaine);
  void htinfo_state_url13(char *chaine);
  void htinfo_state_url14(char *chaine);
  char* htquestion1(void);
  char* htquestion2(void);
  char* htquestion3(void);
  void htcommandend(void);

#ifdef __cplusplus
  }
#endif /* __cplusplus */

==> khttrack-0.11.tar.bz2: khttrack-0.11/khttrack/khttrackmirrorc.h <==
/***************************************************************************
                          khttrackmirrorc.h  -  C link to C++
                             -------------------
    begin                : Wed Sep 4 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly-devel@laposte.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef __cplusplus
  extern "C" {
#endif /* __cplusplus */

  void htinfo_link_detected(char *chaine);
  void htinfo_mirror_info(char *chaine);
  void htinfo_bytes_saved(char *chaine);
  void htinfo_time(char *chaine);
  void htinfo_files_written(char *chaine);
  void htinfo_transfer_rate(char *chaine);
  void htinfo_files_updated(char *chaine);
  void htinfo_active_connections(char *chaine);
  void htinfo_errors(char *chaine);
  void htinfo_state_url(char *chaine);
  void htinfo_state_url1(char *chaine);
  void htinfo_state_url2(char *chaine);
  void htinfo_state_url3(char *chaine);
  void htinfo_state_url4(char *chaine);
  void htinfo_state_url5(char *chaine);
  void htinfo_state_url6(char *chaine);
  void htinfo_state_url7(char *chaine);
  void htinfo_state_url8(char *chaine);
  void htinfo_state_url9(char *chaine);
  void htinfo_state_url10(char *chaine);
  void htinfo_state_url11(char *chaine);
  void htinfo_state_url12(char *chaine);
  void htinfo_state_url13(char *chaine);
  void htinfo_state_url14(char *chaine);
  char* htquestion1(void);
  char* htquestion2(void);
  char* htquestion3(void);
  void htcommandend(void);

#ifdef __cplusplus
  }
#endif /* __cplusplus */
